@@ -7,7 +7,7 @@ Module for writing SMS to Email.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -42,13 +42,13 @@ if Wammu.gammu_error == None:
 HEADER_FORMAT = 'X-Wammu-%s'
 CID_FORMAT = '%d*sms@wammu.sms'
 PARTS_TO_HEADER = [
-        'Folder', 
-        'Memory', 
-        'Location', 
-        'Name', 
-        'Type', 
-        'State', 
-        'Class', 
+        'Folder',
+        'Memory',
+        'Location',
+        'Name',
+        'Type',
+        'State',
+        'Class',
         'MessageReference',
         ]
 
@@ -111,18 +111,19 @@ def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
         msg.add_header(HEADER_FORMAT % header, unicode(sms['SMS'][0][header]))
     msg.add_header(HEADER_FORMAT % 'SMSC', sms['SMS'][0]['SMSC']['Number'])
     if sms['SMS'][0]['SMSCDateTime'] is not None:
-        msg.add_header(HEADER_FORMAT % 'SMSCDate', 
+        msg.add_header(HEADER_FORMAT % 'SMSCDate',
                 DateToString(sms['SMS'][0]['SMSCDateTime']))
 
-    remote = '%s<%s@wammu.sms>' % (name, sms['Number'])
-    local = cfg.Read('/MesageExport/From')
+    remote = '%s<%s@wammu.sms>' % (name, sms['Number'].replace(' ', '_'))
+    local = cfg.Read('/MessageExport/From')
+
     if sms['SMS'][0]['Type'] == 'Submit':
         msg['To'] = remote
         msg['From'] = local
     else:
         msg['To'] = local
         msg['From'] = remote
-        prepend = ('Received: from %s via GSM\n' % 
+        prepend = ('Received: from %s via GSM\n' %
                 unicode(sms['SMS'][0]['SMSC']['Number'])) + prepend
 
     if len(sms['Name']) > 0 :
@@ -199,16 +200,17 @@ def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
 
     if sms['DateTime'] is not None:
         filename = '%s-%s-%s.eml' % (
-                sms['SMS'][0]['Type'], 
-                sms['DateTime'].strftime("%Y%m%d%H%M%S"), 
+                sms['SMS'][0]['Type'],
+                sms['DateTime'].strftime("%Y%m%d%H%M%S"),
                 md5.new(sms['Text'].encode('utf-8')).hexdigest())
     else:
         filename = '%s-%s.eml' % (
-                sms['SMS'][0]['Type'], 
+                sms['SMS'][0]['Type'],
                 md5.new(sms['Text'].encode('utf-8')).hexdigest())
 
     # Add message ID
-    msg.add_header('Message-ID', '<%s@%s>' % (filename[:-4], sms['Number']))
+    msgid = '<%s@%s>' % (filename[:-4], sms['Number'].replace(' ', '_'))
+    msg.add_header('Message-ID', msgid)
 
     if mailbox:
         if sms['DateTime'] is None:
@@ -217,5 +219,5 @@ def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
             timestamp = time.asctime(sms['DateTime'].timetuple())
         prepend = ('From wammu@wammu.sms %s\n' % timestamp) + prepend
 
-    return filename, prepend + msg.as_string()
+    return filename, prepend + msg.as_string(), msgid
 
