@@ -329,8 +329,8 @@ class WammuFrame(wx.Frame):
         menu5 = wx.Menu()
         menu5.Append(501, _('&Save'), _('Save currently retrieved data (except messages) to backup.'))
         menu5.Append(502, _('S&ave messages'), _('Save currently retrieved messages to backup.'))
-        menu5.Append(503, _('&Import'), _('Import data from backup to phone.'))
-        menu5.Append(504, _('I&mport messages'), _('Import messages from backup to phone.'))
+        menu5.Append(503, _('&Import to phone'), _('Import data from backup to phone.'))
+        menu5.Append(504, _('I&mport messages to phone'), _('Import messages from backup to phone.'))
         menu5.AppendSeparator()
         menu5.Append(510, _('Export messages to &emails'), _('Export messages to emails in storage you choose.'))
         menu5.Append(511, _('Export messages to &XML'), _('Export messages to XML file you choose.'))
@@ -2141,13 +2141,17 @@ class WammuFrame(wx.Frame):
                 pass
 
         # Check for PIN
-        code = self.sm.GetSecurityStatus()
-        if code is not None:
-            dlg = wx.PasswordEntryDialog(self,
-                _('Please enter %s code:') % code,
-                _('Phone asks for security code'))
-            if dlg.ShowModal() == wx.ID_OK:
-                self.sm.EnterSecurityCode(code, dlg.GetValue())
+        if self.connected:
+            try:
+                code = self.sm.GetSecurityStatus()
+            except gammu.GSMError:
+                code = None
+            if code is not None:
+                dlg = wx.PasswordEntryDialog(self,
+                    _('Please enter %s code:') % code,
+                    _('Phone asks for security code'))
+                if dlg.ShowModal() == wx.ID_OK:
+                    self.sm.EnterSecurityCode(code, dlg.GetValue())
 
 
     def DBUSActionCallback(self, id, action):
