@@ -7,7 +7,7 @@ Misc functions like charset conversion, entries parsers,..
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -479,7 +479,7 @@ def GetWebsiteLang():
     (loc, charset) = locale.getdefaultlocale()
     try:
         if loc[:2].lower() == 'cs':
-            return 'cz.'
+            return 'cs.'
         return ''
     except TypeError:
         return ''
@@ -546,3 +546,44 @@ def CheckDeviceNode(curdev):
                 (_('Maybe you need to be member of %s group.') % group)
                 )
     return (0, '', '', '')
+
+def CompatConfig(cfg):
+    '''
+    Adjust configuration for possible changes in Gammu history.
+    '''
+
+    # 1.27.0 changed handling of boolean options
+    # Pre 1.27.0 used strings
+    if tuple(map(int, gammu.Version()[1].split('.'))) < (1, 27, 0):
+        if cfg['SyncTime']:
+            cfg['SyncTime'] = 'yes'
+        else:
+            cfg['SyncTime'] = 'no'
+        if cfg['LockDevice']:
+            cfg['LockDevice'] = 'yes'
+        else:
+            cfg['LockDevice'] = 'no'
+        if cfg['StartInfo']:
+            cfg['StartInfo'] = 'yes'
+        else:
+            cfg['StartInfo'] = 'no'
+    # 1.27.0 accepted only numbers
+    if tuple(map(int, gammu.Version()[1].split('.'))) == (1, 27, 0):
+        if cfg['SyncTime']:
+            cfg['SyncTime'] = 1
+        else:
+            cfg['SyncTime'] = 0
+        if cfg['LockDevice']:
+            cfg['LockDevice'] = 1
+        else:
+            cfg['LockDevice'] = 0
+        if cfg['StartInfo']:
+            cfg['StartInfo'] = 1
+        else:
+            cfg['StartInfo'] = 0
+
+    # Older versions did not use model auto
+    if cfg['Model'] == 'auto':
+        cfg['Model'] = ''
+
+    return cfg
